@@ -18,12 +18,15 @@ def cli() -> None:
 @click.argument("files", nargs=-1)
 @click.option("--host", default="0.0.0.0", help="Host of the SPARQL endpoint")
 @click.option("--port", default=8000, help="Port of the SPARQL endpoint")
-def serve(files: List[str], host: str, port: int) -> None:
-    run_serve(files, host, port)
+@click.option("--store", default="default", help="Store used by RDFLib: default or Oxigraph")
+def serve(files: List[str], host: str, port: int, store: str) -> None:
+    run_serve(files, host, port, store)
 
 
-def run_serve(files: List[str], host: str, port: int) -> None:
-    g = ConjunctiveGraph()
+def run_serve(files: List[str], host: str, port: int, store: str = 'default') -> None:
+    if store == 'oxigraph':
+        store = store.capitalize()
+    g = ConjunctiveGraph(store=store)
     for glob_file in files:
         file_list = glob.glob(glob_file)
         for file in file_list:
@@ -36,7 +39,16 @@ def run_serve(files: List[str], host: str, port: int) -> None:
                 + click.style(str(len(g)), bold=True)
             )
 
-    app = SparqlEndpoint(graph=g)
+    app = SparqlEndpoint(
+        graph=g,
+        example_query="""PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
+PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
+SELECT * WHERE {
+    GRAPH ?g {
+        ?s ?p ?o .
+    }
+} LIMIT 100""",
+    )
     uvicorn.run(app, host=host, port=port)
 
 
